@@ -660,9 +660,9 @@ class TypeConverter(object):
         return start, end + 1
 
 
-class AstBuilder(object):
+class ASTBuilder(object):
 
-    def __init__(self, token_stream, filename, in_class='', visibility=None,
+    def __init__(self, token_stream, filename, in_class=None, visibility=None,
                  namespace_stack=None, quiet=False):
         if namespace_stack is None:
             namespace_stack = []
@@ -676,10 +676,9 @@ class AstBuilder(object):
         self.namespace_stack = namespace_stack[:]
         self.quiet = quiet
         self.in_class = in_class
-        if in_class is None:
-            self.in_class_name_only = None
-        else:
-            self.in_class_name_only = in_class.split('::')[-1]
+        self.in_class_name_only = None
+        if in_class is not None:
+            self.in_class_name_only = in_class.split('::')[-1].split('<')[0]
         self.visibility = visibility
         self.current_token = None
         # Keep the state whether we are currently handling a typedef or not.
@@ -1587,7 +1586,7 @@ class AstBuilder(object):
 
         body = None
         if token.token_type == tokenize.SYNTAX and token.name == '{':
-            ast = AstBuilder(self.get_scope(), self.filename, class_name,
+            ast = ASTBuilder(self.get_scope(), self.filename, class_name,
                              visibility, self.namespace_stack,
                              quiet=self.quiet)
             body = list(ast.generate())
@@ -1717,17 +1716,17 @@ class AstBuilder(object):
 
 
 def builder_from_source(source, filename, quiet=False):
-    """Utility method that returns an AstBuilder from source code.
+    """Utility method that returns an ASTBuilder from source code.
 
     Args:
       source: 'C++ source code'
       filename: 'file1'
 
     Returns:
-      AstBuilder
+      ASTBuilder
 
     """
-    return AstBuilder(tokenize.get_tokens(source, quiet=quiet),
+    return ASTBuilder(tokenize.get_tokens(source, quiet=quiet),
                       filename,
                       quiet=quiet)
 
